@@ -1,6 +1,6 @@
 """API for Wargaming Update Service (WGUS)"""
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 from .metadata import Metadata, get_metadata
-from .patches_chain import PatchesChains, get_patches_chain
+from .patches_chains import PatchesChains, get_patches_chains
